PreparedImport

Struct PreparedImport 

pub struct PreparedImport {
    pub manifest_digest: Digest,
    pub manifest: ImageManifest,
    pub config: ImageConfiguration,
    pub previous_state: Option<Box<LayeredImageState>>,
    pub previous_manifest_digest: Option<Digest>,
    pub previous_imageid: Option<String>,
    pub ostree_layers: Vec<ManifestLayerState>,
    pub ostree_commit_layer: ManifestLayerState,
    pub layers: Vec<ManifestLayerState>,
}
Information about which layers need to be downloaded.

Fields

manifest_digest: Digest

The manifest digest that was found

manifest: ImageManifest

The deserialized manifest.

config: ImageConfiguration

The deserialized configuration.

previous_state: Option<Box<LayeredImageState>>

The previous manifest

previous_manifest_digest: Option<Digest>

The previously stored manifest digest.

previous_imageid: Option<String>

The previously stored image ID.

ostree_layers: Vec<ManifestLayerState>

The layers containing split objects

ostree_commit_layer: ManifestLayerState

The layer for the ostree commit.

layers: Vec<ManifestLayerState>

Any further non-ostree (derived) layers.

Implementations

Source

impl PreparedImport

pub fn all_layers(&self) -> impl Iterator<Item = &ManifestLayerState>

Iterate over all layers; the commit layer, the ostree split object layers, and any non-ostree layers.

pub fn version(&self) -> Option<&str>

Retrieve the container image version.

pub fn deprecated_warning(&self) -> Option<&'static str>

If this image is using any deprecated features, return a message saying so.

pub fn layers_with_history( &self, ) -> impl Iterator<Item = Result<(&ManifestLayerState, &History)>>

Iterate over all layers paired with their history entry. An error will be returned if the history does not cover all entries.

pub fn layers_to_fetch( &self, ) -> impl Iterator<Item = Result<(&ManifestLayerState, &str)>>

Iterate over all layers that are not present, along with their history description.